@@ -109,16 +109,15 @@ def cleanString(string):
 
 if os.path.exists(DATA_FILE):
 	[Station, Line] = cPickle.load(open(DATA_FILE, 'r'))
-	FullLine = {}                                                  
-	for superline in Line[LINE_GROUPS]:                            
-		for line_1 in Line[LINE_GROUPS][superline]:            
-			FullLine[line_1] = Line[LINE_STOP][line_1]     
-			for line_2 in Line[LINE_GROUPS][superline]:    
+	FullLine = {}
+	for superline in Line[LINE_GROUPS]:
+		for line_1 in Line[LINE_GROUPS][superline]:
+			FullLine[line_1] = list(Line[LINE_STOP][line_1])
+			for line_2 in Line[LINE_GROUPS][superline]:
 				if Line[LINE_STOP][line_1][0] == Line[LINE_STOP][line_2][-1]:
-					FullLine[line_1][0:0] = Line[LINE_STOP][line_2][:-1]
+					FullLine[line_1][0:0] = list(Line[LINE_STOP][line_2][:-1])
 				if Line[LINE_STOP][line_1][-1] == Line[LINE_STOP][line_2][0]:
-					FullLine[line_1][-1:-1] = Line[LINE_STOP][line_2][1:]
-	[Station, Line] = cPickle.load(open(DATA_FILE, 'r'))
+					FullLine[line_1][-1:-1] = list(Line[LINE_STOP][line_2][1:])
 else:
 	if not os.path.exists(DATA_DIR):
 		print "Error: Neither data file nor database found."
@@ -207,8 +206,6 @@ def get_closures():
 					try:
 						closed_from = min(FullLine[line].index(cleanString(part[1])), FullLine[line].index(cleanString(part[2])))
 						closed_to = max(FullLine[line].index(cleanString(part[1])), FullLine[line].index(cleanString(part[2])))
-						#closed_from = min(Line[LINE_STOP][line].index(cleanString(part[1])), Line[LINE_STOP][line].index(cleanString(part[2])))
-						#closed_to = max(Line[LINE_STOP][line].index(cleanString(part[1])), Line[LINE_STOP][line].index(cleanString(part[2])))
 						for i in range(closed_to - closed_from):
 							idx = Line[LINE_STOP][line].index(FullLine[line][i + closed_from])
 							if len(part) == 3:
@@ -565,6 +562,7 @@ def main():
 		if (event.time - widget.oldtime) < 250:
 			widget.container.destroy()
 		else:
+			bScrolled = False
 			if route.plan != None:
 				if len(route.plan[0]) > 1:
 					for i in range(len(route.plan[0]) - 1):
@@ -578,6 +576,9 @@ def main():
 								hildon.hildon_banner_show_information(win, 'qgn_note_infoprint', route.guide[i])
 								if len(Station[STATION_COORDS][stop]) == 4:
 									data.scroll_to(int((Station[STATION_COORDS][stop][0] + Station[STATION_COORDS][stop][2])/2*MAP_SCALE), int((Station[STATION_COORDS][stop][1] + Station[STATION_COORDS][stop][3])/2*MAP_SCALE))
+									bScrolled = True
+			if not bScrolled:
+				data.scroll_to(event.x, event.y)
 		widget.oldtime = event.time
 
 	def showdialog(title, route):
